package sun.management;

import java.util.List;
import java.util.HashMap;
import java.util.Map;
import java.util.Iterator;
import java.nio.ByteBuffer;
import sun.management.counter.Counter;
import sun.management.counter.perf.PerfInstrumentation;
import java.io.IOException;
import sun.management.counter.Units;
import sun.misc.Perf;
import java.util.concurrent.atomic.AtomicInteger;

public class ConnectorAddressLink
{
    private static final String CONNECTOR_ADDRESS_COUNTER = "sun.management.JMXConnectorServer.address";
    private static final String REMOTE_CONNECTOR_COUNTER_PREFIX = "sun.management.JMXConnectorServer.";
    private static AtomicInteger counter;
    
    public ConnectorAddressLink() {
    }
    
    public static void export(String s) {
        if (s == null || s.length() == 0) {
            throw new IllegalArgumentException("address not specified");
        }
        Perf.getPerf().createString("sun.management.JMXConnectorServer.address", 1, Units.STRING.intValue(), s);
        return;
    }
    
    public static String importFrom(int n) throws IOException {
        Perf perf = Perf.getPerf();
        ByteBuffer attach;
        try {
            attach = perf.attach(n, "r");
        }
        catch (IllegalArgumentException ex) {
            throw new IOException(ex.getMessage());
        }
        Iterator<Counter> iterator = new PerfInstrumentation(attach).findByPattern("sun.management.JMXConnectorServer.address").iterator();
        if (iterator.hasNext()) {
            return (String)((Counter)iterator.next()).getValue();
        }
        return null;
    }
    
    public static void exportRemote(Map<String, String> map) {
        int andIncrement = ConnectorAddressLink.counter.getAndIncrement();
        Perf perf = Perf.getPerf();
        for (Map.Entry entry : map.entrySet()) {
            perf.createString("sun.management.JMXConnectorServer." + andIncrement + "." + (String)entry.getKey(), 1, Units.STRING.intValue(), (String)entry.getValue());
        }
    }
    
    public static Map<String, String> importRemoteFrom(int n) throws IOException {
        Perf perf = Perf.getPerf();
        ByteBuffer attach;
        try {
            attach = perf.attach(n, "r");
        }
        catch (IllegalArgumentException ex) {
            throw new IOException(ex.getMessage());
        }
        List<Counter> allCounters = new PerfInstrumentation(attach).getAllCounters();
        HashMap<String, String> hashMap = new HashMap();
        for (Counter counter : allCounters) {
            String name = counter.getName();
            if (name.startsWith("sun.management.JMXConnectorServer.") && !name.equals("sun.management.JMXConnectorServer.address")) {
                hashMap.put(name, counter.getValue().toString());
            }
            else {
                continue;
            }
        }
        return hashMap;
    }
    
    static {
        ConnectorAddressLink.counter = new AtomicInteger();
    }
}
